@@ -172,6 +172,22 @@ class Manifest:
         """Get a list of Projects from the manifest."""
         return list(self._projects.values())
 
+    def selected_projects(self, names: Sequence[str]) -> Sequence[ProjectEntry]:
+        """Get a list of Projects from the manifest with the given names."""
+        projects = (
+            list(
+                project for project in self._projects.values() if project.name in names
+            )
+            if names
+            else list(self._projects.values())
+        )
+        if names and len(projects) != len(names):
+            raise RuntimeError(
+                f"Not all projects found! {', '.join(names)}",
+                f"This manifest contains {', '.join([project.name for project in self._projects.values()])}",
+            )
+        return projects
+
     @property
     def remotes(self) -> Sequence[Remote]:
         """Get a list of Remotes from the manifest."""
